basecontrollers

package
v0.0.0-...-99ae320 Latest Latest
Warning

This package is not in the latest version of its module.

Go to latest
Published: Sep 3, 2015 License: GPL-3.0 Imports: 7 Imported by: 0

Documentation

Index

Constants

This section is empty.

Variables

This section is empty.

Functions

func ContentValues

func ContentValues(w *wrapper.Wrapper)

The controller function for Values found directly in the controller values of the element

func DomainPublicValue

func DomainPublicValue(w *wrapper.Wrapper)

The controller function for Values found in the Site Configuration

func GetControllerMap

func GetControllerMap(cm controller.ControllerMap)
func MenuValues(w *wrapper.Wrapper)

The controller function for Values found directly in the controller values of the element

func PathValues

func PathValues(w *wrapper.Wrapper)

The controller function to retrieve elements ids from the path

func SlugValues

func SlugValues(w *wrapper.Wrapper)

The controller function for elements that are context specific

func WrapperValues

func WrapperValues(w *wrapper.Wrapper)

The controller function for Values found directly in the controller values of the element

Types

This section is empty.

Jump to