Documentation
¶
Index ¶
Constants ¶
This section is empty.
Variables ¶
This section is empty.
Functions ¶
Types ¶
type Path ¶
type Path struct {
MongoId bson.ObjectId `bson:"_id,omitempty" json:"id"`
Path string `bson:"path" json:"path"`
Wildcard bool `bson:"wildcard" json:"wildcard"`
Template string `bson:"template" json:"template"`
Status string `bson:"status" json:"status"`
Title string `bson:"title" json:"title"`
PathElements `bson:",inline,omitempty"`
}
Path Structure
func (*Path) PathMatch ¶
Given a URL and status this query will attempt to find a matching path. First the query qill attempt to implicitly match the url without a wildcard Then it will attempt to match based on the same path value having a wildcard After that it will remove sections of the url each time looking for a wildcard match If it does not find any matches it retrns the last error.
type PathElements ¶
type PathElements struct {
Elements []string `bson:"elements,omitempty" json:"elements,omitempty"`
}
PathElements Structure to define the Elements in a path for easy json and bson marshalling.
Click to show internal directories.
Click to hide internal directories.