router

package
v0.0.0-...-99ae320 Latest Latest
Warning

This package is not in the latest version of its module.

Go to latest
Published: Sep 3, 2015 License: GPL-3.0 Imports: 9 Imported by: 0

Documentation

Index

Constants

This section is empty.

Variables

This section is empty.

Functions

This section is empty.

Types

type Router

type Router struct {
	Aliases     configs.Aliases
	Sites       configs.SitesMap
	Controllers controller.ControllerMap
}

The Router should have everything needed to server multiple sites from one go instance Aliases will have all domain aliases with the key for the site configuration Sites will have all the individual configurations with their key that relates to a Alias APIEndPoint is a random string that generates each time a server boots and defines where all API calls will take place.

func New

The Constructor for the Router structure

func (Router) ServeHTTP

func (ro Router) ServeHTTP(w http.ResponseWriter, r *http.Request)

The Serve HTTP method to qualify as a handler interface.

Directories

Path Synopsis

Jump to