jsconfig

package
v0.0.0-...-99ae320 Latest Latest
Warning

This package is not in the latest version of its module.

Go to latest
Published: Sep 3, 2015 License: GPL-3.0 Imports: 2 Imported by: 0

Documentation

Index

Constants

const (
	ConfigScript = `` /* 638-byte string literal not displayed */

)

We are compiling the AngularJs config script into the program for fast loading. All sites should have the same Angular JS config template with different values passed from the site config

Variables

This section is empty.

Functions

This section is empty.

Types

type JsConfigs

type JsConfigs struct {
	APIEndPoint      string
	TemplateEndpoint string
	ForeignDomains   []string
	AngularModules   []string
}

Current available values. This may be reconfigured if it gets too large.

func (*JsConfigs) Serve

func (c *JsConfigs) Serve(w http.ResponseWriter)

Serve the config

Jump to