services

package
v0.0.0-...-99ae320 Latest Latest
Warning

This package is not in the latest version of its module.

Go to latest
Published: Sep 3, 2015 License: GPL-3.0 Imports: 1 Imported by: 0

Documentation

Index

Constants

This section is empty.

Variables

This section is empty.

Functions

func AddMessage

func AddMessage(t string, s string, w *wrapper.Wrapper)

Add a message to be served

func ClearMessage

func ClearMessage(w *wrapper.Wrapper)

func Redirect

func Redirect(r string, w *wrapper.Wrapper)

Set will take a string of the page to redirect to and the wrapper

func SetDynamic

func SetDynamic(d Dynamic, w *wrapper.Wrapper)

Once the above structure is created it can be passed to the dynamic function to be added to the payload. It takes the DynamicLoad struct and the wrapper from the controller

Types

type Dynamic

type Dynamic struct {
	Target     string `json:"target,omitempty"`   // The dynamic id of the dom element being targetted
	Controller string `json:"controller"`         // the controller to invoke
	Id         string `json:"id,omitempty"`       // An id to pass to the element
	Template   string `json:"template,omitempty"` // The template to use
}

The DynamicLoad struct will be marshalled and added to you controller return payload.

Jump to