Documentation
¶
Index ¶
Constants ¶
This section is empty.
Variables ¶
This section is empty.
Functions ¶
func ContentValues ¶
The controller function for Values found directly in the controller values of the element
func DomainPublicValue ¶
The controller function for Values found in the Site Configuration
func GetControllerMap ¶
func GetControllerMap(cm controller.ControllerMap)
func MenuValues ¶
The controller function for Values found directly in the controller values of the element
func PathValues ¶
The controller function to retrieve elements ids from the path
func SlugValues ¶
The controller function for elements that are context specific
func WrapperValues ¶
The controller function for Values found directly in the controller values of the element
Types ¶
This section is empty.
Click to show internal directories.
Click to hide internal directories.