Documentation
¶
Overview ¶
This is the top level configuration loading for Server Config, Site Aliases, and Site Configurations.
Index ¶
Constants ¶
This section is empty.
Variables ¶
var ServerConfigDirectory string
Functions ¶
Types ¶
type Aliases ¶
Simple map for the aliases
func NewAliases ¶
Builder function takes a SiteMap and returns the Aliases Map
type Server ¶
Server Config, Includes some base configurations for the Server
Port: Which port should be served SitesDirectory: Where the individual sites folder is located Log Directory: The directory where logs are stored
var ServerConfig *Server
Where the server configuration directory is set
type SiteConfig ¶
type SiteConfig struct {
MongoDb map[string]string
Directory string
Aliases []string
SessionExpiration time.Duration
TemplateEndpoint string
ForeignDomains []string
AngularModules []string
PublicValues map[string]string
FourOFour string
APIEndPoint string
Controllers []string
ElementControllers []string
Logger *logrus.Logger
DbSession *mgo.Session
RawConfig *viper.Viper
}
func NewSiteConfig ¶
func NewSiteConfig(f string) *SiteConfig
Constructor for SiteConfig, takes config filename as an argument.
Click to show internal directories.
Click to hide internal directories.