Documentation
¶
Index ¶
Constants ¶
This section is empty.
Variables ¶
This section is empty.
Functions ¶
This section is empty.
Types ¶
type Router ¶
type Router struct {
Aliases configs.Aliases
Sites configs.SitesMap
Controllers controller.ControllerMap
}
The Router should have everything needed to server multiple sites from one go instance Aliases will have all domain aliases with the key for the site configuration Sites will have all the individual configurations with their key that relates to a Alias APIEndPoint is a random string that generates each time a server boots and defines where all API calls will take place.
func New ¶
func New(a configs.Aliases, s configs.SitesMap, c controller.ControllerMap) *Router
The Constructor for the Router structure
Click to show internal directories.
Click to hide internal directories.