Documentation
¶
Index ¶
Constants ¶
This section is empty.
Variables ¶
This section is empty.
Functions ¶
func AddMessage ¶
Add a message to be served
func ClearMessage ¶
func SetDynamic ¶
Once the above structure is created it can be passed to the dynamic function to be added to the payload. It takes the DynamicLoad struct and the wrapper from the controller
Types ¶
type Dynamic ¶
type Dynamic struct {
Target string `json:"target,omitempty"` // The dynamic id of the dom element being targetted
Controller string `json:"controller"` // the controller to invoke
Id string `json:"id,omitempty"` // An id to pass to the element
Template string `json:"template,omitempty"` // The template to use
}
The DynamicLoad struct will be marshalled and added to you controller return payload.
Click to show internal directories.
Click to hide internal directories.